@@ -4,7 +4,6 @@ The pngme.api package exposes utilities to interact with Pngme's financial data.
 
 
 from .client import AsyncClient, Client
-from .core import with_concurrency_limit
 from .resources.alerts import Alert
 from .resources.balances import BalanceRecord
 from .resources.credit_report import CreditReport
@@ -14,7 +13,6 @@ from .resources.transactions import TransactionRecord
 __all__ = (
     "AsyncClient",
     "Client",
-    "with_concurrency_limit",
     "Alert",
     "BalanceRecord",
     "CreditReport",
