@@ -4,7 +4,7 @@ from typing import List, Optional, Sequence, Set
 
 from pydantic import BaseModel
 
-from ..core import BaseClient, with_concurrency_limit
+from ..core import BaseClient
 from ..encoders import encode_query_params
 from ..types import AccountType, Currency
 
@@ -101,9 +101,7 @@ class BaseBalancesResource:
                 )
                 for page in range(max_pages - 1)
             ]
-            response_pages = await asyncio.gather(
-                *with_concurrency_limit(coroutines, self._client.concurrency_limit)
-            )
+            response_pages = await asyncio.gather(*coroutines)
             responses = (response, *response_pages)
         else:
             responses = (response,)
@@ -143,7 +141,7 @@ class SyncBalancesResource(BaseBalancesResource):
         utc_endtime: Optional[datetime] = None,
         labels: Optional[Sequence[str]] = None,
     ) -> List[BalanceRecord]:
-        return asyncio.run(
+        return self._client.run(
             self._get(
                 user_uuid=user_uuid,
                 institution_id=institution_id,
