@@ -1,4 +1,3 @@
-import asyncio
 from typing import List
 
 from pydantic import BaseModel
@@ -53,4 +52,4 @@ class AsyncInstitutionsResource(BaseInstitutionsResource):
 
 class SyncInstitutionsResource(BaseInstitutionsResource):
     def get(self, user_uuid: str) -> List[Institution]:
-        return asyncio.run(self._get(user_uuid))
+        return self._client.run(self._get(user_uuid))
