@@ -5,7 +5,7 @@ from typing import List, Optional
 
 from pydantic import BaseModel
 
-from ..core import BaseClient, with_concurrency_limit
+from ..core import BaseClient
 from ..encoders import encode_query_params
 
 PATH = "/users"
@@ -69,9 +69,7 @@ class BaseUsersResource(ABC):
             coroutines = [
                 self._get_page(search, page + 2) for page in range(max_pages - 1)
             ]
-            response_pages = await asyncio.gather(
-                *with_concurrency_limit(coroutines, self._client.concurrency_limit),
-            )
+            response_pages = await asyncio.gather(*coroutines)
             responses = (response, *response_pages)
         else:
             responses = (response,)
@@ -86,4 +84,4 @@ class AsyncUsersResource(BaseUsersResource):
 
 class SyncUsersResource(BaseUsersResource):
     def get(self, search: Optional[str] = None) -> List[User]:
-        return asyncio.run(self._get(search))
+        return self._client.run(self._get(search))
